mdt.gui.qt.tabs package
=======================

Submodules
----------

mdt.gui.qt.tabs.generate_brain_mask_tab module
----------------------------------------------

.. automodule:: mdt.gui.qt.tabs.generate_brain_mask_tab
    :members:
    :undoc-members:
    :show-inheritance:

mdt.gui.qt.tabs.generate_protocol_tab module
--------------------------------------------

.. automodule:: mdt.gui.qt.tabs.generate_protocol_tab
    :members:
    :undoc-members:
    :show-inheritance:

mdt.gui.qt.tabs.generate_roi_mask_tab module
--------------------------------------------

.. automodule:: mdt.gui.qt.tabs.generate_roi_mask_tab
    :members:
    :undoc-members:
    :show-inheritance:

mdt.gui.qt.tabs.view_results_tab module
---------------------------------------

.. automodule:: mdt.gui.qt.tabs.view_results_tab
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: mdt.gui.qt.tabs
    :members:
    :undoc-members:
    :show-inheritance:
